@@ -18,6 +18,7 @@
 from .access_requests import *
 from .appearance import *
 from .applications import *
+from .artifacts import *
 from .audit_events import *
 from .award_emojis import *
 from .badges import *
@@ -39,6 +40,7 @@ from .export_import import *
 from .features import *
 from .files import *
 from .geo_nodes import *
+from .group_access_tokens import *
 from .groups import *
 from .hooks import *
 from .issues import *
@@ -58,9 +60,11 @@ from .packages import *
 from .pages import *
 from .personal_access_tokens import *
 from .pipelines import *
+from .project_access_tokens import *
 from .projects import *
 from .push_rules import *
 from .releases import *
+from .repositories import *
 from .runners import *
 from .services import *
 from .settings import *
