@@ -2,7 +2,7 @@ from typing import Any, cast, Dict, Optional, TYPE_CHECKING, Union
 
 from gitlab import exceptions as exc
 from gitlab import types
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     CRUDMixin,
@@ -12,6 +12,7 @@ from gitlab.mixins import (
     SaveMixin,
     UpdateMixin,
 )
+from gitlab.types import RequiredOptional
 
 from .events import GroupEpicResourceLabelEventManager  # noqa: F401
 
@@ -42,7 +43,7 @@ class GroupEpicManager(CRUDMixin, RESTManager):
     _update_attrs = RequiredOptional(
         optional=("title", "labels", "description", "start_date", "end_date"),
     )
-    _types = {"labels": types.ListAttribute}
+    _types = {"labels": types.CommaSeparatedListAttribute}
 
     def get(self, id: Union[str, int], lazy: bool = False, **kwargs: Any) -> GroupEpic:
         return cast(GroupEpic, super().get(id=id, lazy=lazy, **kwargs))
@@ -72,7 +73,7 @@ class GroupEpicIssue(ObjectDeleteMixin, SaveMixin, RESTObject):
             return
 
         # call the manager
-        obj_id = self.get_id()
+        obj_id = self.encoded_id
         self.manager.update(obj_id, updated_data, **kwargs)
 
 
@@ -106,7 +107,7 @@ class GroupEpicIssueManager(
         """
         if TYPE_CHECKING:
             assert data is not None
-        CreateMixin._check_missing_create_attrs(self, data)
+        self._create_attrs.validate_attrs(data=data)
         path = f"{self.path}/{data.pop('issue_id')}"
         server_data = self.gitlab.http_post(path, **kwargs)
         if TYPE_CHECKING:
