@@ -1,7 +1,9 @@
+from typing import Any, cast, Dict, Tuple, TYPE_CHECKING, Union
+
 from gitlab import cli
 from gitlab import exceptions as exc
 from gitlab import types
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     CRUDMixin,
@@ -16,6 +18,7 @@ from gitlab.mixins import (
     TodoMixin,
     UserAgentDetailMixin,
 )
+from gitlab.types import RequiredOptional
 
 from .award_emojis import ProjectIssueAwardEmojiManager  # noqa: F401
 from .discussions import ProjectIssueDiscussionManager  # noqa: F401
@@ -40,7 +43,7 @@ __all__ = [
 
 class Issue(RESTObject):
     _url = "/issues"
-    _short_print_attr = "title"
+    _repr_attr = "title"
 
 
 class IssueManager(RetrieveMixin, RESTManager):
@@ -63,7 +66,10 @@ class IssueManager(RetrieveMixin, RESTManager):
         "updated_after",
         "updated_before",
     )
-    _types = {"iids": types.ListAttribute, "labels": types.ListAttribute}
+    _types = {"iids": types.ArrayAttribute, "labels": types.CommaSeparatedListAttribute}
+
+    def get(self, id: Union[str, int], lazy: bool = False, **kwargs: Any) -> Issue:
+        return cast(Issue, super().get(id=id, lazy=lazy, **kwargs))
 
 
 class GroupIssue(RESTObject):
@@ -71,7 +77,7 @@ class GroupIssue(RESTObject):
 
 
 class GroupIssueManager(ListMixin, RESTManager):
-    _path = "/groups/%(group_id)s/issues"
+    _path = "/groups/{group_id}/issues"
     _obj_cls = GroupIssue
     _from_parent_attrs = {"group_id": "id"}
     _list_filters = (
@@ -90,7 +96,7 @@ class GroupIssueManager(ListMixin, RESTManager):
         "updated_after",
         "updated_before",
     )
-    _types = {"iids": types.ListAttribute, "labels": types.ListAttribute}
+    _types = {"iids": types.ArrayAttribute, "labels": types.CommaSeparatedListAttribute}
 
 
 class ProjectIssue(
@@ -103,39 +109,40 @@ class ProjectIssue(
     ObjectDeleteMixin,
     RESTObject,
 ):
-    _short_print_attr = "title"
+    _repr_attr = "title"
     _id_attr = "iid"
-    _managers = (
-        ("awardemojis", "ProjectIssueAwardEmojiManager"),
-        ("discussions", "ProjectIssueDiscussionManager"),
-        ("links", "ProjectIssueLinkManager"),
-        ("notes", "ProjectIssueNoteManager"),
-        ("resourcelabelevents", "ProjectIssueResourceLabelEventManager"),
-        ("resourcemilestoneevents", "ProjectIssueResourceMilestoneEventManager"),
-        ("resourcestateevents", "ProjectIssueResourceStateEventManager"),
-    )
+
+    awardemojis: ProjectIssueAwardEmojiManager
+    discussions: ProjectIssueDiscussionManager
+    links: "ProjectIssueLinkManager"
+    notes: ProjectIssueNoteManager
+    resourcelabelevents: ProjectIssueResourceLabelEventManager
+    resourcemilestoneevents: ProjectIssueResourceMilestoneEventManager
+    resourcestateevents: ProjectIssueResourceStateEventManager
 
     @cli.register_custom_action("ProjectIssue", ("to_project_id",))
     @exc.on_http_error(exc.GitlabUpdateError)
-    def move(self, to_project_id, **kwargs):
+    def move(self, to_project_id: int, **kwargs: Any) -> None:
         """Move the issue to another project.
 
         Args:
-            to_project_id(int): ID of the target project
+            to_project_id: ID of the target project
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Raises:
             GitlabAuthenticationError: If authentication is not correct
             GitlabUpdateError: If the issue could not be moved
         """
-        path = "%s/%s/move" % (self.manager.path, self.get_id())
+        path = f"{self.manager.path}/{self.encoded_id}/move"
         data = {"to_project_id": to_project_id}
         server_data = self.manager.gitlab.http_post(path, post_data=data, **kwargs)
+        if TYPE_CHECKING:
+            assert isinstance(server_data, dict)
         self._update_attrs(server_data)
 
     @cli.register_custom_action("ProjectIssue")
     @exc.on_http_error(exc.GitlabGetError)
-    def related_merge_requests(self, **kwargs):
+    def related_merge_requests(self, **kwargs: Any) -> Dict[str, Any]:
         """List merge requests related to the issue.
 
         Args:
@@ -146,14 +153,17 @@ class ProjectIssue(
             GitlabGetErrot: If the merge requests could not be retrieved
 
         Returns:
-            list: The list of merge requests.
+            The list of merge requests.
         """
-        path = "%s/%s/related_merge_requests" % (self.manager.path, self.get_id())
-        return self.manager.gitlab.http_get(path, **kwargs)
+        path = f"{self.manager.path}/{self.encoded_id}/related_merge_requests"
+        result = self.manager.gitlab.http_get(path, **kwargs)
+        if TYPE_CHECKING:
+            assert isinstance(result, dict)
+        return result
 
     @cli.register_custom_action("ProjectIssue")
     @exc.on_http_error(exc.GitlabGetError)
-    def closed_by(self, **kwargs):
+    def closed_by(self, **kwargs: Any) -> Dict[str, Any]:
         """List merge requests that will close the issue when merged.
 
         Args:
@@ -164,14 +174,17 @@ class ProjectIssue(
             GitlabGetErrot: If the merge requests could not be retrieved
 
         Returns:
-            list: The list of merge requests.
+            The list of merge requests.
         """
-        path = "%s/%s/closed_by" % (self.manager.path, self.get_id())
-        return self.manager.gitlab.http_get(path, **kwargs)
+        path = f"{self.manager.path}/{self.encoded_id}/closed_by"
+        result = self.manager.gitlab.http_get(path, **kwargs)
+        if TYPE_CHECKING:
+            assert isinstance(result, dict)
+        return result
 
 
 class ProjectIssueManager(CRUDMixin, RESTManager):
-    _path = "/projects/%(project_id)s/issues"
+    _path = "/projects/{project_id}/issues"
     _obj_cls = ProjectIssue
     _from_parent_attrs = {"project_id": "id"}
     _list_filters = (
@@ -221,7 +234,12 @@ class ProjectIssueManager(CRUDMixin, RESTManager):
             "discussion_locked",
         ),
     )
-    _types = {"iids": types.ListAttribute, "labels": types.ListAttribute}
+    _types = {"iids": types.ArrayAttribute, "labels": types.CommaSeparatedListAttribute}
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectIssue:
+        return cast(ProjectIssue, super().get(id=id, lazy=lazy, **kwargs))
 
 
 class ProjectIssueLink(ObjectDeleteMixin, RESTObject):
@@ -229,29 +247,38 @@ class ProjectIssueLink(ObjectDeleteMixin, RESTObject):
 
 
 class ProjectIssueLinkManager(ListMixin, CreateMixin, DeleteMixin, RESTManager):
-    _path = "/projects/%(project_id)s/issues/%(issue_iid)s/links"
+    _path = "/projects/{project_id}/issues/{issue_iid}/links"
     _obj_cls = ProjectIssueLink
     _from_parent_attrs = {"project_id": "project_id", "issue_iid": "iid"}
     _create_attrs = RequiredOptional(required=("target_project_id", "target_issue_iid"))
 
     @exc.on_http_error(exc.GitlabCreateError)
-    def create(self, data, **kwargs):
+    # NOTE(jlvillal): Signature doesn't match CreateMixin.create() so ignore
+    # type error
+    def create(  # type: ignore
+        self, data: Dict[str, Any], **kwargs: Any
+    ) -> Tuple[RESTObject, RESTObject]:
         """Create a new object.
 
         Args:
-            data (dict): parameters to send to the server to create the
+            data: parameters to send to the server to create the
                          resource
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Returns:
-            RESTObject, RESTObject: The source and target issues
+            The source and target issues
 
         Raises:
             GitlabAuthenticationError: If authentication is not correct
             GitlabCreateError: If the server cannot perform the request
         """
-        self._check_missing_create_attrs(data)
+        self._create_attrs.validate_attrs(data=data)
+        if TYPE_CHECKING:
+            assert self.path is not None
         server_data = self.gitlab.http_post(self.path, post_data=data, **kwargs)
+        if TYPE_CHECKING:
+            assert isinstance(server_data, dict)
+            assert self._parent is not None
         source_issue = ProjectIssue(self._parent.manager, server_data["source_issue"])
         target_issue = ProjectIssue(self._parent.manager, server_data["target_issue"])
         return source_issue, target_issue
