@@ -1,7 +1,7 @@
 from typing import Any, cast, Union
 
 from gitlab import types
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CRUDMixin,
     DeleteMixin,
@@ -10,6 +10,7 @@ from gitlab.mixins import (
     RetrieveMixin,
     SaveMixin,
 )
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "GroupBillableMember",
