@@ -11,7 +11,7 @@ import gitlab
 from gitlab import cli
 from gitlab import exceptions as exc
 from gitlab import types
-from gitlab.base import RequiredOptional, RESTManager, RESTObject, RESTObjectList
+from gitlab.base import RESTManager, RESTObject, RESTObjectList
 from gitlab.mixins import (
     CRUDMixin,
     ListMixin,
@@ -23,6 +23,7 @@ from gitlab.mixins import (
     TimeTrackingMixin,
     TodoMixin,
 )
+from gitlab.types import RequiredOptional
 
 from .award_emojis import ProjectMergeRequestAwardEmojiManager  # noqa: F401
 from .commits import ProjectCommit, ProjectCommitManager
@@ -95,10 +96,10 @@ class MergeRequestManager(ListMixin, RESTManager):
         "deployed_after",
     )
     _types = {
-        "approver_ids": types.ListAttribute,
-        "approved_by_ids": types.ListAttribute,
-        "in": types.ListAttribute,
-        "labels": types.ListAttribute,
+        "approver_ids": types.ArrayAttribute,
+        "approved_by_ids": types.ArrayAttribute,
+        "in": types.CommaSeparatedListAttribute,
+        "labels": types.CommaSeparatedListAttribute,
     }
 
 
@@ -133,9 +134,9 @@ class GroupMergeRequestManager(ListMixin, RESTManager):
         "wip",
     )
     _types = {
-        "approver_ids": types.ListAttribute,
-        "approved_by_ids": types.ListAttribute,
-        "labels": types.ListAttribute,
+        "approver_ids": types.ArrayAttribute,
+        "approved_by_ids": types.ArrayAttribute,
+        "labels": types.CommaSeparatedListAttribute,
     }
 
 
@@ -199,8 +200,6 @@ class ProjectMergeRequest(
             all: If True, return all the items, without pagination
             per_page: Number of items to retrieve per request
             page: ID of the page to return (starts with page 1)
-            as_list: If set to False and no pagination option is
-                defined, return a generator instead of a list
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Raises:
@@ -211,7 +210,7 @@ class ProjectMergeRequest(
             List of issues
         """
         path = f"{self.manager.path}/{self.encoded_id}/closes_issues"
-        data_list = self.manager.gitlab.http_list(path, as_list=False, **kwargs)
+        data_list = self.manager.gitlab.http_list(path, iterator=True, **kwargs)
         if TYPE_CHECKING:
             assert isinstance(data_list, gitlab.GitlabList)
         manager = ProjectIssueManager(self.manager.gitlab, parent=self.manager._parent)
@@ -226,8 +225,6 @@ class ProjectMergeRequest(
             all: If True, return all the items, without pagination
             per_page: Number of items to retrieve per request
             page: ID of the page to return (starts with page 1)
-            as_list: If set to False and no pagination option is
-                defined, return a generator instead of a list
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Raises:
@@ -239,7 +236,7 @@ class ProjectMergeRequest(
         """
 
         path = f"{self.manager.path}/{self.encoded_id}/commits"
-        data_list = self.manager.gitlab.http_list(path, as_list=False, **kwargs)
+        data_list = self.manager.gitlab.http_list(path, iterator=True, **kwargs)
         if TYPE_CHECKING:
             assert isinstance(data_list, gitlab.GitlabList)
         manager = ProjectCommitManager(self.manager.gitlab, parent=self.manager._parent)
@@ -263,7 +260,7 @@ class ProjectMergeRequest(
         path = f"{self.manager.path}/{self.encoded_id}/changes"
         return self.manager.gitlab.http_get(path, **kwargs)
 
-    @cli.register_custom_action("ProjectMergeRequest", tuple(), ("sha",))
+    @cli.register_custom_action("ProjectMergeRequest", (), ("sha",))
     @exc.on_http_error(exc.GitlabMRApprovalError)
     def approve(self, sha: Optional[str] = None, **kwargs: Any) -> Dict[str, Any]:
         """Approve the merge request.
@@ -347,7 +344,7 @@ class ProjectMergeRequest(
 
     @cli.register_custom_action(
         "ProjectMergeRequest",
-        tuple(),
+        (),
         (
             "merge_commit_message",
             "should_remove_source_branch",
@@ -455,10 +452,10 @@ class ProjectMergeRequestManager(CRUDMixin, RESTManager):
         "wip",
     )
     _types = {
-        "approver_ids": types.ListAttribute,
-        "approved_by_ids": types.ListAttribute,
-        "iids": types.ListAttribute,
-        "labels": types.ListAttribute,
+        "approver_ids": types.ArrayAttribute,
+        "approved_by_ids": types.ArrayAttribute,
+        "iids": types.ArrayAttribute,
+        "labels": types.CommaSeparatedListAttribute,
     }
 
     def get(
