@@ -35,6 +35,11 @@ def test_markdown(gl):
     assert "foo" in html
 
 
+def test_markdown_in_project(gl, project):
+    html = gl.markdown("foo", project=project.path_with_namespace)
+    assert "foo" in html
+
+
 def test_lint(gl):
     success, errors = gl.lint("Invalid")
     assert success is False
@@ -120,11 +125,16 @@ def test_namespaces(gl):
 
 def test_notification_settings(gl):
     settings = gl.notificationsettings.get()
-    settings.level = gitlab.const.NOTIFICATION_LEVEL_WATCH
+    settings.level = gitlab.const.NotificationLevel.WATCH
     settings.save()
 
     settings = gl.notificationsettings.get()
-    assert settings.level == gitlab.const.NOTIFICATION_LEVEL_WATCH
+    assert settings.level == gitlab.const.NotificationLevel.WATCH
+
+
+def test_search(gl):
+    result = gl.search(scope=gitlab.const.SearchScope.USERS, search="Administrator")
+    assert result[0]["id"] == 1
 
 
 def test_user_activities(gl):
@@ -220,9 +230,25 @@ def test_list_all_true_nowarning(gl):
     assert len(items) > 20
 
 
-def test_list_as_list_false_nowarning(gl):
-    """Using `as_list=False` will disable the warning"""
+def test_list_iterator_true_nowarning(gl):
+    """Using `iterator=True` will disable the warning"""
     with warnings.catch_warnings(record=True) as caught_warnings:
-        items = gl.gitlabciymls.list(as_list=False)
+        items = gl.gitlabciymls.list(iterator=True)
     assert len(caught_warnings) == 0
     assert len(list(items)) > 20
+
+
+def test_list_as_list_false_warnings(gl):
+    """Using `as_list=False` will disable the UserWarning but cause a
+    DeprecationWarning"""
+    with warnings.catch_warnings(record=True) as caught_warnings:
+        items = gl.gitlabciymls.list(as_list=False)
+    assert len(caught_warnings) == 1
+    for warning in caught_warnings:
+        assert isinstance(warning.message, DeprecationWarning)
+    assert len(list(items)) > 20
+
+
+def test_list_with_as_list_and_iterator_raises(gl):
+    with pytest.raises(ValueError, match="`as_list` or `iterator`"):
+        gl.gitlabciymls.list(as_list=False, iterator=True)
