@@ -3,9 +3,20 @@ import uuid
 import pytest
 
 import gitlab
+from gitlab.const import AccessLevel
 from gitlab.v4.objects.projects import ProjectStorage
 
 
+def test_projects_head(gl):
+    headers = gl.projects.head()
+    assert headers["x-total"]
+
+
+def test_project_head(gl, project):
+    headers = gl.projects.head(project.id)
+    assert headers["content-type"] == "application/json"
+
+
 def test_create_project(gl, user):
     # Moved from group tests chunk in legacy tests, TODO cleanup
     admin_project = gl.projects.create({"name": "admin_project"})
@@ -15,7 +26,7 @@ def test_create_project(gl, user):
     sudo_project = gl.projects.create({"name": "sudo_project"}, sudo=user.id)
 
     created = gl.projects.list()
-    created_gen = gl.projects.list(as_list=False)
+    created_gen = gl.projects.list(iterator=True)
     owned = gl.projects.list(owned=True)
 
     assert admin_project in created and sudo_project in created
@@ -26,6 +37,17 @@ def test_create_project(gl, user):
     sudo_project.delete()
 
 
+def test_project_members(user, project):
+    member = project.members.create(
+        {"user_id": user.id, "access_level": AccessLevel.DEVELOPER}
+    )
+    assert member in project.members.list()
+    assert member.access_level == 30
+
+    member.delete()
+    assert member not in project.members.list()
+
+
 def test_project_badges(project):
     badge_image = "http://example.com"
     badge_link = "http://example/img.svg"
