@@ -9,8 +9,6 @@ from gitlab import GitlabHttpError, GitlabList, GitlabParsingError, RedirectErro
 from gitlab.client import RETRYABLE_TRANSIENT_ERROR_CODES
 from tests.unit import helpers
 
-MATCH_EMPTY_QUERY_PARAMS = [responses.matchers.query_param_matcher({})]
-
 
 def test_build_url(gl):
     r = gl._build_url("http://localhost/api/v4")
@@ -29,7 +27,7 @@ def test_http_request(gl):
         url=url,
         json=[{"name": "project1"}],
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     http_r = gl.http_request("get", "/projects")
@@ -46,7 +44,7 @@ def test_http_request_404(gl):
         url=url,
         json={},
         status=400,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
@@ -63,7 +61,7 @@ def test_http_request_with_only_failures(gl, status_code):
         url=url,
         json={},
         status=status_code,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
@@ -322,7 +320,7 @@ def test_http_request_302_get_does_not_raise(gl):
             method=responses.GET,
             url=url,
             status=302,
-            match=MATCH_EMPTY_QUERY_PARAMS,
+            match=helpers.MATCH_EMPTY_QUERY_PARAMS,
         )
         gl.http_request(verb=method, path=api_path)
 
@@ -346,7 +344,7 @@ def test_http_request_302_put_raises_redirect_error(gl):
             method=responses.PUT,
             url=url,
             status=302,
-            match=MATCH_EMPTY_QUERY_PARAMS,
+            match=helpers.MATCH_EMPTY_QUERY_PARAMS,
         )
         with pytest.raises(RedirectError) as exc:
             gl.http_request(verb=method, path=api_path)
@@ -364,7 +362,7 @@ def test_get_request(gl):
         url=url,
         json={"name": "project1"},
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     result = gl.http_get("/projects")
@@ -382,7 +380,7 @@ def test_get_request_raw(gl):
         content_type="application/octet-stream",
         body="content",
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     result = gl.http_get("/projects")
@@ -398,7 +396,7 @@ def test_get_request_404(gl):
         url=url,
         json=[],
         status=404,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
@@ -415,7 +413,7 @@ def test_get_request_invalid_data(gl):
         body='["name": "project1"]',
         content_type="application/json",
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabParsingError):
@@ -425,6 +423,22 @@ def test_get_request_invalid_data(gl):
     assert responses.assert_call_count(url, 1) is True
 
 
+@responses.activate
+def test_head_request(gl):
+    url = "http://localhost/api/v4/projects"
+    responses.add(
+        method=responses.HEAD,
+        url=url,
+        headers={"X-Total": "1"},
+        status=200,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
+    )
+
+    result = gl.http_head("/projects")
+    assert isinstance(result, requests.structures.CaseInsensitiveDict)
+    assert result["X-Total"] == "1"
+
+
 @responses.activate
 def test_list_request(gl):
     url = "http://localhost/api/v4/projects"
@@ -434,16 +448,16 @@ def test_list_request(gl):
         json=[{"name": "project1"}],
         headers={"X-Total": "1"},
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with warnings.catch_warnings(record=True) as caught_warnings:
-        result = gl.http_list("/projects", as_list=True)
+        result = gl.http_list("/projects", iterator=False)
     assert len(caught_warnings) == 0
     assert isinstance(result, list)
     assert len(result) == 1
 
-    result = gl.http_list("/projects", as_list=False)
+    result = gl.http_list("/projects", iterator=True)
     assert isinstance(result, GitlabList)
     assert len(list(result)) == 1
 
@@ -480,16 +494,34 @@ large_list_response = {
     ],
     "headers": {"X-Total": "30", "x-per-page": "20"},
     "status": 200,
-    "match": MATCH_EMPTY_QUERY_PARAMS,
+    "match": helpers.MATCH_EMPTY_QUERY_PARAMS,
 }
 
 
+@responses.activate
+def test_as_list_deprecation_warning(gl):
+    responses.add(**large_list_response)
+
+    with warnings.catch_warnings(record=True) as caught_warnings:
+        result = gl.http_list("/projects", as_list=False)
+    assert len(caught_warnings) == 1
+    warning = caught_warnings[0]
+    assert isinstance(warning.message, DeprecationWarning)
+    message = str(warning.message)
+    assert "`as_list=False` is deprecated" in message
+    assert "Use `iterator=True` instead" in message
+    assert __file__ == warning.filename
+    assert not isinstance(result, list)
+    assert len(list(result)) == 20
+    assert len(responses.calls) == 1
+
+
 @responses.activate
 def test_list_request_pagination_warning(gl):
     responses.add(**large_list_response)
 
     with warnings.catch_warnings(record=True) as caught_warnings:
-        result = gl.http_list("/projects", as_list=True)
+        result = gl.http_list("/projects", iterator=False)
     assert len(caught_warnings) == 1
     warning = caught_warnings[0]
     assert isinstance(warning.message, UserWarning)
@@ -503,10 +535,10 @@ def test_list_request_pagination_warning(gl):
 
 
 @responses.activate
-def test_list_request_as_list_false_nowarning(gl):
+def test_list_request_iterator_true_nowarning(gl):
     responses.add(**large_list_response)
     with warnings.catch_warnings(record=True) as caught_warnings:
-        result = gl.http_list("/projects", as_list=False)
+        result = gl.http_list("/projects", iterator=True)
     assert len(caught_warnings) == 0
     assert isinstance(result, GitlabList)
     assert len(list(result)) == 20
@@ -554,7 +586,7 @@ def test_list_request_404(gl):
         url=url,
         json=[],
         status=404,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
@@ -571,7 +603,7 @@ def test_list_request_invalid_data(gl):
         body='["name": "project1"]',
         content_type="application/json",
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabParsingError):
@@ -587,7 +619,7 @@ def test_post_request(gl):
         url=url,
         json={"name": "project1"},
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     result = gl.http_post("/projects")
@@ -604,7 +636,7 @@ def test_post_request_404(gl):
         url=url,
         json=[],
         status=404,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
@@ -621,7 +653,7 @@ def test_post_request_invalid_data(gl):
         content_type="application/json",
         body='["name": "project1"]',
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabParsingError):
@@ -637,7 +669,7 @@ def test_put_request(gl):
         url=url,
         json={"name": "project1"},
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     result = gl.http_put("/projects")
@@ -654,7 +686,7 @@ def test_put_request_404(gl):
         url=url,
         json=[],
         status=404,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
@@ -671,7 +703,7 @@ def test_put_request_invalid_data(gl):
         body='["name": "project1"]',
         content_type="application/json",
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabParsingError):
@@ -687,7 +719,7 @@ def test_delete_request(gl):
         url=url,
         json=True,
         status=200,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     result = gl.http_delete("/projects")
@@ -704,7 +736,7 @@ def test_delete_request_404(gl):
         url=url,
         json=[],
         status=404,
-        match=MATCH_EMPTY_QUERY_PARAMS,
+        match=helpers.MATCH_EMPTY_QUERY_PARAMS,
     )
 
     with pytest.raises(GitlabHttpError):
